from setuptools import setup

with open("README.md", encoding='utf-8', mode='r') as fh:
    long_description = fh.read()

setup(name='newconan',
      version='1.99',
      description='New cmake project based on conan',
      long_description=long_description,
      long_description_content_type="text/markdown",
      url='https://github.com/wumo-util/newconan',
      author='wumo',
      license='MIT',
      packages=['newconan'],
      entry_points={
          'console_scripts': ['newconan=newconan.newconan:main'],
      },
      install_requires=[
          'conan'
      ],
      python_requires='>=3.6',
      include_package_data=True,
      zip_safe=False)



from conans import ConanFile, CMake, tools

class {project_name}Conan(ConanFile):
    name = "{project_name}"
    version = "0.0.1"
    settings = "os", "compiler", "build_type", "arch"
    requires = ()
    generators = "cmake"
    scm = {
        "type": "git",
        "subfolder": name,
        "url": "auto",
        "revision": "auto"
    }
    options = {
        "shared": [True, False],
    }
    default_options = {
        "shared": {is_shared}
    }

    def configure_cmake(self):
        cmake = CMake(self)
        cmake.definitions["BUILD_TEST"] = False
        cmake.definitions["BUILD_SHARED"] = self.options.shared
        cmake.configure(source_folder=self.name)
        return cmake

    def build(self):
        cmake = self.configure_cmake()
        cmake.build()

    def imports(self):
        self.copy("*.dll", dst="bin", src="bin")
        self.copy("*.dll", dst="bin", src="lib")
        self.copy("*.dylib", dst="bin", src="lib")
        self.copy("*.pdb", dst="bin", src="bin")

    def package(self):
        cmake = self.configure_cmake()
        cmake.install()
    
    def package_info(self):
        self.cpp_info.libs = tools.collect_libs(self)
